2024-08-22 Version: 1.4.3
- Update API GetJobRun: update response param.


2024-08-20 Version: 1.4.2
- Update API ListJobRuns: update response param.
- Update API ListReleaseVersions: update response param.
- Update API ListSessionClusters: update response param.
- Update API ListWorkspaces: update response param.
- Update API StartJobRun: update param body.


2024-07-09 Version: 1.4.1
- Update API ListSessionClusters: add param kind.
- Update API ListSessionClusters: update response param.


2024-05-31 Version: 1.4.0
- Support API CreateSqlStatement.
- Support API GetSqlStatement.
- Support API TerminateSqlStatement.
- Update API ListJobRuns: add param jobRunDeploymentId.


2024-05-22 Version: 1.3.0
- Support API AddMembers.
- Support API GrantRoleToUsers.


2024-05-21 Version: 1.2.0
- Support API ListSessionClusters.


2024-05-21 Version: 1.2.0
- Support API ListSessionClusters.


2024-05-20 Version: 1.1.0
- Support API ListReleaseVersions.
- Support API ListWorkspaceQueues.
- Support API ListWorkspaces.


2024-05-17 Version: 1.0.1
- Update API CancelJobRun: update param workspaceId.
- Update API CancelJobRun: update param jobRunId.
- Update API GetJobRun: update param workspaceId.
- Update API GetJobRun: update param jobRunId.
- Update API ListJobRuns: update param workspaceId.
- Update API StartJobRun: update param workspaceId.


2024-04-16 Version: 1.0.0
- Generated python 2023-08-08 for emr-serverless-spark.

